#include "stm8s.h"
#include "uart.h"

#define TX_BUFFER_SIZE (countof(TxBuffer) - 1)

/* Private macro -------------------------------------------------------------*/
#define countof(a)   (sizeof(a) / sizeof(*(a)))

uint8_t TxBuffer[] = "HyperTerminal Interrupt: UART1-Hyperterminal communication using Interrupt\n";
__IO uint8_t TxCounter = 0;
void UART1_Config(void)
{
  /* EVAL COM (UART) configuration -----------------------------------------*/
  /* USART configured as follow:
        - BaudRate = 115200 baud
        - Word Length = 8 Bits
        - One Stop Bit
        - Odd parity
        - Receive and transmit enabled
        - UART Clock disabled
  */
  UART1_DeInit();
  UART1_Init((uint32_t)115200, UART1_WORDLENGTH_8D,UART1_STOPBITS_1, UART1_PARITY_NO,
                   UART1_SYNCMODE_CLOCK_DISABLE, UART1_MODE_TXRX_ENABLE);

  /* Enable the UART Receive interrupt: this interrupt is generated when the UART
    receive data register is not empty */
  UART1_ITConfig(UART1_IT_RXNE_OR, ENABLE);

  /* Enable the UART Transmit complete interrupt: this interrupt is generated
     when the UART transmit Shift Register is empty */
  UART1_ITConfig(UART1_IT_TXE, ENABLE);

  /* Enable UART */
  UART1_Cmd(ENABLE);

    /* Enable general interrupts */
  //enableInterrupts();
}

static void UART1_TX_IRQHandler (void) __interrupt(17)
{
  /* Write one byte to the transmit data register */
  UART1_SendData8(TxBuffer[TxCounter++]);

  if (TxCounter == TX_BUFFER_SIZE)
  {
    /* Disable the USART Transmit Complete interrupt */
    UART1_ITConfig(UART1_IT_TXE, DISABLE);
  }
}
static void UART1_RX_IRQHandler (void) __interrupt(18)
{
  uint8_t temp;

  /* Read one byte from the receive data register and send it back */
  temp = (UART1_ReceiveData8() & 0x7F);
  UART1_SendData8(temp);
}
